@@ -24,6 +24,7 @@ import os
 import cairo
 import ConfigParser
 import subprocess
+import osso
 
 supports_alpha = False
 
@@ -47,12 +48,15 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       settings = self.get_settings()
       self.image, url = self.get_data(settings['search_engine'])
 
+      self.osso_context = osso.Context("org.maemo.touchsearch", "1.1", False)
+      self.osso_rpc = osso.Rpc(self.osso_context)
+
       self.hbox = gtk.HBox()
       
       self.s_eventbox = gtk.EventBox()
       self.s_eventbox.add(self.image)
       self.s_eventbox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
-      self.s_eventbox.connect("button-press-event", self.search_dialog)
+      self.s_eventbox.connect("button-press-event", self.search_dialog, self.osso_rpc)
 
       #self.select_button = gtk.Button()
       self.e_eventbox = gtk.EventBox()
@@ -197,7 +201,7 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       self.s_eventbox.show_all()
       self.set_app_settings(widget, engine)
 
-   def search_dialog(self, widget, data=None):
+   def search_dialog(self, widget, event, osso_rpc):
       settings = self.get_settings()
       dialog = gtk.Dialog("Type A Search Query", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
       search_button = dialog.add_button("Search", 1)
@@ -209,7 +213,7 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       hbox.pack_start(image, False, False, 5)
       hbox.pack_end(entry, True, True, 5)
       
-      search_button.connect('clicked', self.search_the_web, entry, url)
+      search_button.connect('clicked', self.search_the_web, entry, url, osso_rpc)
       dialog.vbox.pack_start(hbox)
       dialog.show_all()
       dialog.run()
@@ -231,12 +235,11 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       response = dialog.run()
       dialog.destroy()
       
-   def search_the_web(self, widget, entry, url):
+   def search_the_web(self, widget, entry, url, osso_rpc):
       query = entry.get_text()
       url_scheme = url % query
       print url_scheme
-      call = 'dbus-send --system --type=method_call --dest="com.nokia.osso_browser" --print-reply /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"%s"' % url_scheme
-      subprocess.Popen(call, shell=True)
+      osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (url_scheme,))
 
    def get_data(self, engine):
       settings = self.get_settings()
